# Stone Soup

## Background
Stone Soup is a software project to provide the target tracking and state estimation
community with a framework for the development and testing of tracking and state
estimation algorithms.

Stone Soup is currently in *beta*.

Please see the
[Stone Soup documentation](https://stonesoup.readthedocs.org/) for more
information.

## Dependencies
Stone Soup uses the following dependencies:

| Name | License |
| ---- | ------- |
| [Python](https://www.python.org/) (v3.5+) | PSFL |
| [SciPy](https://www.scipy.org/) | BSD |
| [matplotlib](https://matplotlib.org/) | [PSF/BSD-compatible](https://matplotlib.org/users/license.html) |
| [ruamel.yaml](https://yaml.readthedocs.io/) | MIT |
| [pymap3d](https://github.com/scivision/pymap3d) | MIT |
| [utm](https://https://github.com/Turbo87/utm) | MIT |

### Development
For development the following libraries are also recommended:

| Name | License |
| ---- | ------- |
| [Sphinx](https://www.sphinx-doc.org/) | BSD |
| [pytest](https://docs.pytest.org/) | MIT |
| [Flake8](https://flake8.pycqa.org/) | MIT |
| [Coverage.py](https://coverage.readthedocs.io/) | Apache 2.0 |

## License
Stone Soup is released under MIT License. Please see [License](LICENSE) for details.
